#[non_exhaustive]pub struct FunctionInfo {
pub name: Option<String>,
pub name_what: Option<&'static str>,
pub what: &'static str,
pub source: Option<String>,
pub short_src: Option<String>,
pub line_defined: Option<usize>,
pub last_line_defined: Option<usize>,
pub num_upvalues: u8,
pub num_params: u8,
pub is_vararg: bool,
}Expand description
Contains information about a function.
Please refer to the Lua Debug Interface for more information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>A (reasonable) name of the function (None if the name cannot be found).
name_what: Option<&'static str>Explains the name field (can be global/local/method/field/upvalue/etc).
Always None for Luau.
what: &'static strA string Lua if the function is a Lua function, C if it is a C function, main if it is
the main part of a chunk.
source: Option<String>Source of the chunk that created the function.
short_src: Option<String>A “printable” version of source, to be used in error messages.
line_defined: Option<usize>The line number where the definition of the function starts.
last_line_defined: Option<usize>The line number where the definition of the function ends (not set by Luau).
num_upvalues: u8The number of upvalues of the function.
num_params: u8lua51 nor crate feature luajit.The number of parameters of the function (always 0 for C).
is_vararg: boollua51 nor crate feature luajit.Whether the function is a variadic function (always true for C).